httpserver

package
v0.0.12 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2026 License: MIT Imports: 22 Imported by: 0

Documentation

Index

Constants

const (
	// TLSErrorPageDeadline is the deadline for completing TLS error page handshake
	TLSErrorPageDeadline = 10 * time.Second

	// TLSClientHelloDeadline is the deadline for reading TLS ClientHello
	TLSClientHelloDeadline = 10 * time.Second

	// TLSTunnelStartTimeout is the timeout for starting a tunnel for TLS connections
	TLSTunnelStartTimeout = 30 * time.Second

	// TLSBackendDialTimeout is the timeout for dialing the backend service
	TLSBackendDialTimeout = 10 * time.Second
)

Timeout constants for HTTP server operations

Variables

This section is empty.

Functions

This section is empty.

Types

type Manager

type Manager interface {
	GetOrCreateTunnel(hostname string, scheme string) (tunnelmgr.TunnelHandle, error)
}

type Server

type Server struct {
	// contains filtered or unexported fields
}

func NewServer

func NewServer(cfg *config.Config, mgr Manager) *Server

func (*Server) ServeHTTP

func (s *Server) ServeHTTP(w http.ResponseWriter, r *http.Request)

func (*Server) Shutdown

func (s *Server) Shutdown(ctx context.Context) error

func (*Server) Start

func (s *Server) Start() error

Jump to